@@ -68,16 +68,15 @@ class NextcloudApp(app_module.App):
                                clients=manifest.clients, tags=manifest.tags)
         self.add(info)
 
-        menu_item = menu.Menu('menu-nextcloud', info.name,
-                              info.short_description, info.icon_filename,
-                              'nextcloud:index', parent_url_name='apps')
+        menu_item = menu.Menu('menu-nextcloud', info.name, info.icon_filename,
+                              info.tags, 'nextcloud:index',
+                              parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut('shortcut-nextcloud', info.name,
-                                      short_description=info.short_description,
                                       icon=info.icon_filename,
                                       url='/nextcloud/', clients=info.clients,
-                                      login_required=True)
+                                      tags=info.tags, login_required=True)
         self.add(shortcut)
 
         packages = Packages('packages-nextcloud', [
