@@ -54,15 +54,13 @@ class TTRSSApp(app_module.App):
                                donation_url='https://www.patreon.com/cthulhoo')
         self.add(info)
 
-        menu_item = menu.Menu('menu-ttrss', info.name, info.short_description,
-                              info.icon_filename, 'ttrss:index',
-                              parent_url_name='apps')
+        menu_item = menu.Menu('menu-ttrss', info.name, info.icon_filename,
+                              info.tags, 'ttrss:index', parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut('shortcut-ttrss', info.name,
-                                      short_description=info.short_description,
                                       icon=info.icon_filename, url='/tt-rss',
-                                      clients=info.clients,
+                                      clients=info.clients, tags=info.tags,
                                       login_required=True,
                                       allowed_groups=list(groups))
         self.add(shortcut)
